--- main/rtp.c.orig	2009-08-06 17:05:54.000000000 +0000
+++ main/rtp.c	2009-08-06 17:13:22.000000000 +0000
@@ -90,6 +90,8 @@
 static int nochecksums;
 #endif
 
+static int rtpfixdtmf;          /* A flag to indicate if an RTP packet needs to be sent prior to sending DTMF.  This help Sonus recognize the RFC2833 packets. */
+
 /* Uncomment this to enable more intense native bridging, but note: this is currently buggy */
 /* #define P2P_INTENSE */
 
@@ -2256,6 +2258,24 @@
 	int hdrlen = 12, res = 0, i = 0, payload = 0;
 	char data[256];
 
+	if (rtpfixdtmf)
+	{
+		unsigned char silent_data[160];
+		struct ast_frame silent_frame;
+
+		/* A better solution would be to convert this frame to the last codec, but sending a ulaw packet seems to work for Sonus */
+		memset(&silent_frame, 0, sizeof(silent_frame));
+		memset(silent_data, 0xff, sizeof(silent_data));
+		silent_frame.frametype = AST_FRAME_VOICE;
+		silent_frame.subclass = AST_FORMAT_ULAW;
+		silent_frame.data = silent_data;
+		silent_frame.datalen = sizeof(silent_data);
+		silent_frame.samples = 160;
+		silent_frame.src = "RTP";
+
+		ast_rtp_write(rtp, &silent_frame);
+	}
+
 	if ((digit <= '9') && (digit >= '0'))
 		digit -= '0';
 	else if (digit == '*')
@@ -3865,6 +3885,7 @@
 	rtpstart = 5000;
 	rtpend = 31000;
 	dtmftimeout = DEFAULT_DTMF_TIMEOUT;
+	rtpfixdtmf = 0;
 	cfg = ast_config_load("rtp.conf");
 	if (cfg) {
 		if ((s = ast_variable_retrieve(cfg, "general", "rtpstart"))) {
@@ -3909,6 +3930,9 @@
 				dtmftimeout = DEFAULT_DTMF_TIMEOUT;
 			};
 		}
+		if ((s = ast_variable_retrieve(cfg, "general", "rtpfixdtmf"))) {
+			rtpfixdtmf = ast_true(s);
+		}
 		ast_config_destroy(cfg);
 	}
 	if (rtpstart >= rtpend) {